@@ -4,7 +4,7 @@
 
 package Net::LDAP::Constant;
 
-$VERSION = "0.05";
+$VERSION = "0.07";
 
 use Carp;
 
@@ -135,60 +135,32 @@ error codes.
 
 Operation completed without error
 
-=item LDAP_PP_PASSWORD_EXPIRED (0)
-
-The account's password has expired.
-
 =item LDAP_OPERATIONS_ERROR (1)
 
 Server encountered an internal error
 
-=item LDAP_PP_ACCOUNT_LOCKED (1)
-
-The account is locked.
-
 =item LDAP_PROTOCOL_ERROR (2)
 
 Unrecognized version number or incorrect PDU structure
 
-=item LDAP_PP_CHANGE_AFTER_RESET (2)
-
-The account's password has been reset and now must be changed.
-
 =item LDAP_TIMELIMIT_EXCEEDED (3)
 
 The time limit on a search operation has been exceeded
 
-=item LDAP_PP_PASSWORD_MOD_NOT_ALLOWED (3)
-
-The account's password may not be modified.
-
 =item LDAP_SIZELIMIT_EXCEEDED (4)
 
 The maximum number of search results to return has been exceeded.
 
-=item LDAP_PP_MUST_SUPPLY_OLD_PASSWORD (4)
-
-The old password must also be supplied when setting a new password.
-
 =item LDAP_COMPARE_FALSE (5)
 
 This code is returned when a compare request completes and the attribute value
 given is not in the entry specified
 
-=item LDAP_PP_INSUFFICIENT_PASSWORD_QUALITY (5)
-
-The new password was not of sufficient quality.
-
 =item LDAP_COMPARE_TRUE (6)
 
 This code is returned when a compare request completes and the attribute value
 given is in the entry specified
 
-=item LDAP_PP_PASSWORD_TOO_SHORT (6)
-
-The new password was too short.
-
 =item LDAP_AUTH_METHOD_NOT_SUPPORTED (7)
 
 Unrecognized SASL mechanism name
@@ -197,18 +169,10 @@ Unrecognized SASL mechanism name
 
 Unrecognized SASL mechanism name
 
-=item LDAP_PP_PASSWORD_TOO_YOUNG (7)
-
-The previous password was changed too recently.
-
 =item LDAP_STRONG_AUTH_REQUIRED (8)
 
 The server requires authentication be performed with a SASL mechanism
 
-=item LDAP_PP_PASSWORD_IN_HISTORY (8)
-
-The new password was used too recently.
-
 =item LDAP_PARTIAL_RESULTS (9)
 
 Returned to version 2 clients when a referral is returned. The response
@@ -511,6 +475,98 @@ The referral hop limit has been exceeded.
 
 =item LDAP_CONTROL_PASSWORDPOLICY (1.3.6.1.4.1.42.2.27.8.5.1)
 
+=item LDAP_CONTROL_PREREAD (1.3.6.1.1.13.1)
+
+=item LDAP_CONTROL_POSTREAD (1.3.6.1.1.13.2)
+
+=item LDAP_CONTROL_ASSERTION (1.3.6.1.1.12)
+
+=item LDAP_CONTROL_SYNC (1.3.6.1.4.1.4203.1.9.1.1)
+
+=item LDAP_CONTROL_SYNC_STATE (1.3.6.1.4.1.4203.1.9.1.2)
+
+=item LDAP_CONTROL_SYNC_DONE (1.3.6.1.4.1.4203.1.9.1.3)
+
+=item LDAP_SYNC_INFO (1.3.6.1.4.1.4203.1.9.1.4)
+
+=back
+
+=head2 Control constants
+
+=over 4
+
+=item LDAP_PP_PASSWORD_EXPIRED (0) [LDAP_CONTROL_PASSWORDPOLICY]
+
+The account's password has expired.
+
+=item LDAP_PP_ACCOUNT_LOCKED (1) [LDAP_CONTROL_PASSWORDPOLICY]
+
+The account is locked.
+
+=item LDAP_PP_CHANGE_AFTER_RESET (2) [LDAP_CONTROL_PASSWORDPOLICY]
+
+The account's password has been reset and now must be changed.
+
+=item LDAP_PP_PASSWORD_MOD_NOT_ALLOWED (3) [LDAP_CONTROL_PASSWORDPOLICY]
+
+The account's password may not be modified.
+
+=item LDAP_PP_MUST_SUPPLY_OLD_PASSWORD (4) [LDAP_CONTROL_PASSWORDPOLICY]
+
+The old password must also be supplied when setting a new password.
+
+=item LDAP_PP_INSUFFICIENT_PASSWORD_QUALITY (5) [LDAP_CONTROL_PASSWORDPOLICY]
+
+The new password was not of sufficient quality.
+
+=item LDAP_PP_PASSWORD_TOO_SHORT (6) [LDAP_CONTROL_PASSWORDPOLICY]
+
+The new password was too short.
+
+=item LDAP_PP_PASSWORD_TOO_YOUNG (7) [LDAP_CONTROL_PASSWORDPOLICY]
+
+The previous password was changed too recently.
+
+=item LDAP_PP_PASSWORD_IN_HISTORY (8) [LDAP_CONTROL_PASSWORDPOLICY]
+
+The new password was used too recently.
+
+=item LDAP_SYNC_NONE (0) [LDAP_CONTROL_SYNC]
+
+=item LDAP_SYNC_REFRESH_ONLY (1) [LDAP_CONTROL_SYNC]
+
+=item LDAP_SYNC_RESERVED (2) [LDAP_CONTROL_SYNC]
+
+=item LDAP_SYNC_REFRESH_AND_PERSIST (3) [LDAP_CONTROL_SYNC]
+
+=item LDAP_SYNC_REFRESH_PRESENTS (0) [LDAP_SYNC_INFO]
+
+=item LDAP_SYNC_REFRESH_DELETES (1) [LDAP_SYNC_INFO]
+
+=item LDAP_TAG_SYNC_NEW_COOKIE (0x80) [LDAP_SYNC_INFO]
+
+=item LDAP_TAG_SYNC_REFRESH_DELETE (0xa1) [LDAP_SYNC_INFO]
+
+=item LDAP_TAG_SYNC_REFRESH_PRESENT (0xa2) [LDAP_SYNC_INFO]
+
+=item LDAP_TAG_SYNC_ID_SET (0xa3) [LDAP_SYNC_INFO]
+
+=item LDAP_TAG_SYNC_COOKIE (0x04) [LDAP_SYNC_INFO]
+
+=item LDAP_TAG_REFRESHDELETES (0x01) [LDAP_SYNC_INFO]
+
+=item LDAP_TAG_REFRESHDONE (0x01) [LDAP_SYNC_INFO]
+
+=item LDAP_TAG_RELOAD_HINT (0x01) [LDAP_CONTROL_SYNC]
+
+=item LDAP_SYNC_PRESENT (0) [LDAP_CONTROL_SYNC_STATE]
+
+=item LDAP_SYNC_ADD (1) [LDAP_CONTROL_SYNC_STATE]
+
+=item LDAP_SYNC_MODIFY (2) [LDAP_CONTROL_SYNC_STATE]
+
+=item LDAP_SYNC_DELETE (3) [LDAP_CONTROL_SYNC_STATE]
+
 =back
 
 =head2 Extension OIDs
@@ -534,6 +590,24 @@ Indicates that the server supports the "Who am I?" extension (draft-zeilenga-lda
 
 =back
 
+=head2 Feature OIDs
+
+B<Net::LDAP::Constant> exports constant subroutines for the following LDAP
+feature OIDs.
+
+=over 4
+
+=item LDAP_FEATURE_ALL_OPATTS (1.3.6.1.4.1.4203.1.5.1)
+
+Indicates if the server allows "+" for returning all operational attributes
+(RFC 3673)
+
+=item LDAP_FEATURE_MODIFY_INCREMENT (1.3.6.1.1.14)
+
+Indicates if the server supports the Modify Increment extension (RFC 4525)
+
+=back
+
 =head1 SEE ALSO
 
 L<Net::LDAP>,
