@@ -8,11 +8,12 @@ use strict;
 use vars qw(@ISA $VERSION);
 use Net::LDAP::Message;
 use Net::LDAP::Entry;
+use Net::LDAP::Intermediate;
 use Net::LDAP::Filter;
 use Net::LDAP::Constant qw(LDAP_SUCCESS LDAP_DECODING_ERROR);
 
 @ISA = qw(Net::LDAP::Message);
-$VERSION = "0.11";
+$VERSION = "0.12";
 
 
 sub first_entry { # compat
@@ -63,6 +64,17 @@ sub decode {
 
     return $self;
   }
+  elsif ($data = delete $result->{protocolOp}{intermediateResponse}) {
+
+    my $intermediate = Net::LDAP::Intermediate->from_asn($data);
+
+    push(@{$self->{'intermediate'} ||= []}, [$intermediate]);
+
+    $self->{callback}->($self, $intermediate)
+      if (defined $self->{callback});
+
+    return $self;
+  }
 
   $self->set_error(LDAP_DECODING_ERROR, "LDAP decode error");
   return;
